#include "db_bsql.h"

/* commands to interface between the SQL parser and the Typhoon DB */

struct BSQL_SETTINGS bsql_settings_global = {
	"\t", "\n"
};

struct BSQL_SETTINGS *bsql_settings = &bsql_settings_global;

/* ========================================================= JOINS */
/* JOIN t1 and t2 based on table expression 'expr' */
struct BSQL_TMPTBL * bsql_join_on( struct BSQL_TMPTBL *t1,
					struct BSQL_TMPTBL *t2, void *expr  ){
	return(NULL);
}
/* JOIN t1 and t2 using columns 'col' */
struct BSQL_TMPTBL * bsql_join_using( struct BSQL_TMPTBL *t1,
					struct BSQL_TMPTBL *t2, struct BSQL_COL *col  ){
	return(NULL);
}
/* JOIN t1 and t2 based on common columns */
struct BSQL_TMPTBL * bsql_join_natural( struct BSQL_TMPTBL *t1, 
						    struct BSQL_TMPTBL *t2  ){
	return(NULL);
}


//SELECT table.field FROM table WHERE table.field = value
int bsql_select_op() {
	return(0);
}
//INSERT	INTO table ( field...) VALUES (val...)
int bsql_insert_op() {
	return(0);
}
//UPDATE	table SET field = value WHERE field.table = value
int bsql_update_op(){
	return(0);
}
//DELETE	FROM table WHERE field.table = value
int bsql_delete_op(){
	return(0);
}

/*
	delete from table/index : if index do find, else iterate and 
	                          build a list for each criteria
	hmmm ... join
					  
*/

//CURSOR   OPEN cursor; FETCH cursor INTO :x, :y; CLOSE cursor
int bsql_cursor_open(){
	return(0);
}
int bsql_cursor_add(){
	return(0);
}
int bsql_cursor_current(){
	return(0);
}
int bsql_cursor_fetch(){
	return(0);
}
int bsql_cursor_close(){
	return(0);
}
